<?php
/**
 * Magento
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License (AFL 3.0)
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://opensource.org/licenses/afl-3.0.php
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@magentocommerce.com so we can send you a copy immediately.
 *
 * @category    SuperMailingList/SuperWebMailer
 * @package     sml_swm
 * @author      Mirko Boeer <info@supermailer.de>
 * @copyright   2018 Mirko Boeer
 * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 */

class sml_swm_Helper_Data extends Mage_Core_Helper_Abstract
{
  public function getConfiguration(){
    $temp = Mage::getStoreConfig('sml/swm/swmlswm_mailinglist_to_store_id');
    if($temp != ""){
       $temp = @unserialize($temp);
       if($temp === false)
          $temp = array();
    } else $temp = array();
    $config = array(
                   'smlswm_url' => Mage::getStoreConfig('sml/swm/smlswm_url'),
                   'smlswm_apikey' => Mage::getStoreConfig('sml/swm/smlswm_apikey'),
                   'swmlswm_mailinglist_to_store_id' => $temp,
                   'complete' => false
                );
    $config['complete'] = !empty($config["smlswm_url"]) && !empty($config["smlswm_apikey"]) && count($config["swmlswm_mailinglist_to_store_id"]);
    return $config;
  }

  public function saveConfiguration($smlswm_url, $smlswm_apikey, $swmlswm_mailinglist_to_store_id){
    Mage::getConfig()->saveConfig('sml/swm/smlswm_url', $smlswm_url);
    Mage::getConfig()->saveConfig('sml/swm/smlswm_apikey', $smlswm_apikey);
    Mage::getConfig()->saveConfig('sml/swm/swmlswm_mailinglist_to_store_id', serialize($swmlswm_mailinglist_to_store_id));
    Mage::app()->getConfig()->reinit();
  }

 public function getswmlswm_mailinglistIdsFromStoreID($config, $StoreId){
   $result = array();
   for($i=0; $i<count($config["swmlswm_mailinglist_to_store_id"]); $i++){
     if($config["swmlswm_mailinglist_to_store_id"][$i]["magentoshop_id"] == $StoreId)
       $result[] = $config["swmlswm_mailinglist_to_store_id"][$i]["smlswm_mailinglist_id"];
   }
   return $result;
 }

 public function getShops(){
   $shops_array = array();
   $shops = Mage::app()->getStores();
   foreach ($shops as $shop) {
        $shops_array[] = array(
            'store_id' => $shop->store_id,
            'name' => $shop->name
        );
   }
   return $shops_array;
 }

 public function test_swmsml_connection($config){
   $createData = array();
   $data = array("api_Common__api_testAPI" => json_encode($createData) );

   $ret = $this->DoHTTPPOSTRequest( $this->RemoveTrailingSlash($config["smlswm_url"]) . "/api/api_json.php", $data, array("APIToken" => $config["smlswm_apikey"]));
   if(!$ret) return "HTTP request to " . $this->RemoveTrailingSlash($config["smlswm_url"]) . "/api/api_json.php" . " failed.";

   $j = json_decode($ret, true);
   if(json_last_error() === JSON_ERROR_NONE){
      if(isset($j["error_code"])) {
        return $j["error"];
      }
      return "OK";
   }else{
      return "HTTP request to " . $this->RemoveTrailingSlash($config["smlswm_url"]) . "/api/api_json.php" . " with JSON-Error failed, JSON code " . $ret;
   }

 }

 public function addRecipientToMailingList($config, $smlswm_mailinglist_id, $email){
   $createData = array("apiMailingListId" => $smlswm_mailinglist_id, "apiData" => array( "u_EMail" => $email ), "apiarrayGroupsIds" => array(), "apiUseDoubleOptIn" => false, "apiFormId" => 0);
   $data = array("api_Recipients__api_createRecipient" => json_encode($createData) );

   $this->DoHTTPPOSTRequest( $this->RemoveTrailingSlash($config["smlswm_url"]) . "/api/api_json.php", $data, array("APIToken" => $config["smlswm_apikey"]));
 }

 public function removeRecipientFromMailingList($config, $smlswm_mailinglist_id, $email){
   $recipients_id = $this->smlswm_getRecipientIdFromEMailAddress($config, $smlswm_mailinglist_id, $email);
   if(intval($recipients_id)){

     $createData = array("apiMailingListId" => $smlswm_mailinglist_id, "apiRecipientIds" => array(intval($recipients_id)));
     $data = array("api_Recipients__api_removeRecipient" => json_encode($createData) );

     $this->DoHTTPPOSTRequest( $this->RemoveTrailingSlash($config["smlswm_url"]) . "/api/api_json.php", $data, array("APIToken" => $config["smlswm_apikey"]));
   }
 }

 public function editRecipientInMailingList($config, $smlswm_mailinglist_id, $email, $email_new){
   $recipients_id = $this->smlswm_getRecipientIdFromEMailAddress($config, $smlswm_mailinglist_id, $email);
   if(intval($recipients_id)){

     $createData = array("apiMailingListId" => $smlswm_mailinglist_id, "apiRecipientId" => intval($recipients_id), "apiData" => array( "u_EMail" => $email_new ));
     $data = array("api_Recipients__api_editRecipient" => json_encode($createData) );

     $this->DoHTTPPOSTRequest( $this->RemoveTrailingSlash($config["smlswm_url"]) . "/api/api_json.php", $data, array("APIToken" => $config["smlswm_apikey"]));
   }
 }

 public function sendDebugEMail($message, $array = null){
   return; // no debug emails!
   if($array && is_array($array))
     foreach($array as $key => $value)
        $message .= "$key: $value\r\n";
   if($array && !is_array($array))
      $message .= "$array\r\n";
   mail('', 'Debug email', $message);
 }

 private function DoHTTPPOSTRequest($URL, $data, $userdefinedheaders = array()){
     $peer_key = version_compare(PHP_VERSION, '5.6.0', '<') ? 'CN_name' : 'peer_name';

     $header="";
     foreach($userdefinedheaders as $key => $value)
       $header .= "$key: $value\r\n";

     if(is_array($data))
       $data = http_build_query($data);

     $aurl = parse_url($URL);

     if($aurl === false || empty($aurl["scheme"]) || empty($aurl["host"]) ) return false;

     $port = 80;
     if($aurl["scheme"] == "https")
       $port = 443;

     $options = array(
             'http' => array(
                 'header' => "Content-type: application/x-www-form-urlencoded\r\n".$header,
                 'method' => "POST",
                 'content' => $data,
                 'Connection: close',
                 'verify_peer' => true,
                 'timeout' => 30,
                 $peer_key => $aurl["host"],
             ),
         );

     $context = stream_context_create($options);
     $ret = file_get_contents($URL, false, $context);
     if($ret === false)
       return false;
     else {
       $this->sendDebugEMail("DoHTTPPOSTRequest \r\nData:" . $data."\r\n", $ret);
       return $ret;
     }
   }

 private function RemoveTrailingSlash($pathname) {
   if(substr($pathname, strlen($pathname) - 1) == "/")
      return substr($pathname, 0, strlen($pathname) - 1);
      else
      return $pathname;
 }

 private function smlswm_getRecipientIdFromEMailAddress($config, $smlswm_mailinglist_id, $email){

   $createData = array("apiMailingListId" => $smlswm_mailinglist_id, "apiRecipientsEMailAddress" => $email);
   $data = array("api_Recipients__api_getRecipientIdFromEMailAddress" => json_encode($createData) );

   $ret = $this->DoHTTPPOSTRequest($this->RemoveTrailingSlash($config["smlswm_url"]) . "/api/api_json.php", $data, array("APIToken" => $config["smlswm_apikey"]));

   if( $ret !== false ){
     $j = json_decode($ret, true);
     if(json_last_error() === JSON_ERROR_NONE){

        if(is_array($j))
          return 0;
          else
          return intval($j);

     }else{
        return intval($ret);
     }
   } else
     return 0;
 }

}